@@ -61,9 +61,11 @@ calcPheno = function(pop,varE,reps,p,simParam){
 #' 
 #' @param pop an object of \code{\link{Pop-class}} or 
 #' \code{\link{HybridPop-class}}
-#' @param varE error variances for phenotype. A vector of length 
-#' nTraits for independent error or a square matrix of dimensions 
-#' nTraits for correlated errors. If NULL, value in simParam is used.
+#' @param h2 a vector of desired narrow-sense heritabilities for
+#' each trait. See details.
+#' @param H2 a vector of desired broad-sense heritabilities for
+#' each trait. See details.
+#' @param varE error (co)variances for traits. See details.
 #' @param reps number of replications for phenotype. See details.
 #' @param fixEff fixed effect to assign to the population. Used 
 #' by genomic selection models only.
@@ -74,11 +76,32 @@ calcPheno = function(pop,varE,reps,p,simParam){
 #' @param simParam an object of \code{\link{SimParam}}
 #' 
 #' @details
+#' There are three arguments for setting the error variance of a 
+#' phenotype: h2, H2, and varE. The user should only use one of these 
+#' arguments. If the user supplies values for more than one, only one 
+#' will be used according to order in which they are listed above.
+#' 
+#' The h2 argument allows the user to specify the error variance 
+#' according to narrow-sense heritability. This calculation uses the
+#' additive genetic variance and total genetic variance in the founder 
+#' population. Thus, the heritability relates to the founder population 
+#' and not the current population.
+#' 
+#' The H2 argument allows the user to specify the error variance 
+#' according to broad-sense heritability. This calculation uses the
+#' total genetic variance in the founder population. Thus, the heritability 
+#' relates to the founder population and not the current population.
+#' 
+#' The varE argument allows the user to specify the error variance
+#' directly. The user may supply a vector describing the error variance 
+#' for each trait or supply a matrix that specify the covariance of 
+#' the errors.
+#' 
 #' The reps parameter is for convient representation of replicated data. 
 #' It is intended to represent replicated yield trials in plant 
 #' breeding programs. In this case, varE is set to the plot error and 
 #' reps is set to the number of plots per entry. The resulting phenotype 
-#' represents entry means.
+#' represents the entry-means.
 #' 
 #' @return Returns an object of \code{\link{Pop-class}} or 
 #' \code{\link{HybridPop-class}} if onlyPheno=FALSE, if 
@@ -99,13 +122,44 @@ calcPheno = function(pop,varE,reps,p,simParam){
 #' pop = setPheno(pop, varE=1)
 #' 
 #' @export
-setPheno = function(pop,varE=NULL,reps=1,fixEff=1L,p=NULL,
-                    onlyPheno=FALSE,simParam=NULL){
+setPheno = function(pop,h2=NULL,H2=NULL,varE=NULL,reps=1,
+                    fixEff=1L,p=NULL,onlyPheno=FALSE,
+                    simParam=NULL){
   if(is.null(simParam)){
     simParam = get("SP",envir=.GlobalEnv)
   }
+  
+  # Calculate varE if using h2 or H2
+  if(!is.null(h2)){
+    if(length(h2)==1){
+      h2 = rep(h2, simParam$nTraits)
+    }
+    stopifnot(length(h2)==simParam$nTraits,
+              all(simParam$varG>0),
+              all(simParam$varA>0))
+    varE = numeric(simParam$nTraits)
+    for(i in 1:length(h2)){
+      tmp = simParam$varA[i]/h2[i]-simParam$varG[i]
+      if(tmp<0){
+        stop(paste0("h2=",h2[i]," is not possible for trait ",i))
+      }
+      varE[i] = tmp
+    }
+  }else if(!is.null(H2)){
+    if(length(H2)==1){
+      H2 = rep(H2, simParam$nTraits)
+    }
+    stopifnot(length(H2)==simParam$nTraits)
+    varE = numeric(simParam$nTraits)
+    for(i in 1:length(H2)){
+      tmp = simParam$varG[i]/H2[i]-simParam$varG[i]
+      varE[i] = tmp
+    }
+  }
+  
+  # Create phenotypes
   pheno = calcPheno(pop=pop,varE=varE,reps=reps,p=p,
-                        simParam=simParam)
+                    simParam=simParam)
   if(onlyPheno){
     return(pheno)
   }
@@ -116,3 +170,5 @@ setPheno = function(pop,varE=NULL,reps=1,fixEff=1L,p=NULL,
   }
   return(pop)
 }
+
+
