@@ -50,7 +50,7 @@ test_that("randCross",{
   SP = SimParam$new(founderPop=founderPop)
   SP$addTraitA(nQtlPerChr=1,mean=0,var=1)
   SP$setTrackPed(TRUE)
-  SP$setGender("yes_sys")
+  SP$setSexes("yes_sys")
   pop = newPop(founderPop,simParam=SP)
   crossPlan = cbind(rep(1,10),rep(2,10))
   pop1 = randCross(pop=pop,nCrosses=1,nProgeny=10,simParam=SP)
@@ -64,7 +64,7 @@ test_that("randCross2",{
   SP = SimParam$new(founderPop=founderPop)
   SP$addTraitA(nQtlPerChr=1,mean=0,var=1)
   SP$setTrackPed(TRUE)
-  SP$setGender("yes_sys")
+  SP$setSexes("yes_sys")
   pop = newPop(founderPop,simParam=SP)
   crossPlan = cbind(rep(1,10),rep(2,10))
   pop1 = randCross2(females=pop,males=pop,nCrosses=1,nProgeny=10,simParam=SP)
@@ -106,7 +106,7 @@ test_that("selectCross",{
   SP = SimParam$new(founderPop=founderPop)
   SP$addTraitA(nQtlPerChr=1,mean=0,var=1)
   SP$setTrackPed(TRUE)
-  SP$setGender("yes_sys")
+  SP$setSexes("yes_sys")
   pop = newPop(founderPop,simParam=SP)
   pop1 = selectCross(pop=pop,nFemale=1,nMale=1,use="rand",nCrosses=2,simParam=SP)
   expect_equal(SP$lastId,4L)
